#
# spec file for package xf86-video-ati
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define xserver_glamor 1
Name:           xf86-video-ati
Version:        18.1.0
Release:        lp151.1.3
Summary:        ATI video driver for the Xorg X server
License:        MIT
Group:          System/X11/Servers/XF86_4
Url:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.bz2
Source1:        http://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.bz2.sig
Source2:        %{name}.keyring
BuildRequires:  autoconf >= 2.60
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(damageproto)
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(gbm)
# Libdrm 2.4.36 needed for kms
BuildRequires:  pkgconfig(libdrm) >= 2.4.58
BuildRequires:  pkgconfig(libdrm_radeon) >= 2.4.58
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(pciaccess) >= 0.8.0
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(renderproto)
BuildRequires:  pkgconfig(videoproto)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xf86driproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xorg-server) >= 1.15
BuildRequires:  pkgconfig(xproto)
Supplements:    modalias(xorg-x11-server:pci:v00001002d*sv*sd*bc03sc*i*)
# This was part of the xorg-x11-driver-video package up to version 7.6
Conflicts:      xorg-x11-driver-video <= 7.6
ExcludeArch:    s390 s390x
%{x11_abi_videodrv_req}
# Glamor is new and we want that now
%if !%{xserver_glamor}
BuildRequires:  pkgconfig(glamor) >= 0.3.1
%endif

%description
ati is an Xorg driver for ATI/AMD video cards.

It autodetects whether your hardware has a Radeon, Rage 128, or Mach64
or earlier class of chipset, and loads the radeon, r128, or mach64
driver as appropriate.

%prep
%setup -q

%build
autoreconf -fiv
%configure \
  --enable-glamor
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%files
%doc COPYING README
%dir %{_libdir}/xorg/modules/drivers
%{_datadir}/X11/xorg.conf.d/10-radeon.conf
%{_libdir}/xorg/modules/drivers/ati_drv.so
%{_libdir}/xorg/modules/drivers/radeon_drv.so
%{_mandir}/man4/ati.4%{?ext_man}
%{_mandir}/man4/radeon.4%{?ext_man}

%changelog
* Sat Sep 15 2018 sndirsch@suse.com
- Update to release 18.1.0
  * This release supports xserver versions 1.13-1.20.
  * Fixed random screen corruption and crashes when using GLAMOR with Xorg
    1.20.
  * Support for leasing RandR outputs to clients.
  * Various robustness fixes for TearFree. In particular, fixed several
    cases in which disabling TearFree at runtime would result in the Xorg
    process freezing or crashing.
  * Fixed some m4 related build issues with older versions of autotools.
* Thu Aug 16 2018 sndirsch@suse.com
- Update to release 18.0.99 (git describe: 18.0.1-44-g740f0850)
  * supposed to provide a fix for boo#1100759, fdo#107528, fdo#105381
* Wed Apr  4 2018 sndirsch@suse.com
- Update to release 18.0.1
  * This release supports xserver versions 1.13-1.19. It also works with
    xserver 1.20 RC1, so unless something unexpected happens, it should work
    with xserver 1.20 as well.
    This is a bug-fix release addressing issues in 18.0.0. While those
    issues shouldn't affect most users, I recommend that all users of 18.0.0
    update to 18.0.1.
    + The Xorg process could crash when multiple primary screens are
    configured in xorg.conf.
    + TearFree could trigger debugging messages in the pixman library
* Wed Mar  7 2018 sndirsch@suse.com
- "I'm pleased to announce the 18.0.0 release of xf86-video-ati, the Xorg
  driver for ATI/AMD Radeon GPUs supported by the radeon kernel driver.
  This release supports xserver versions 1.13-1.19. It also works with
  xserver 1.20 RC1, so unless something unexpected happens, it should work
  with xserver 1.20 as well."
  Highlights:
  * New year-based versioning scheme
  * Page flipping can now be used even when the HW cursor can't be used in
    some cases
  * Support for 30-bit RGB colour output. Note that gamma correction is
    currently not available with 30-bit colour. Also, GLAMOR hardware
    acceleration is not available with 30-bit colour with xserver versions
    before 1.20.
  Plus other improvements and fixes. Thanks to everybody who contributed
  to this release in any way!
* Thu Dec 14 2017 tchvatal@suse.com
- Stick to use pkgconfig style dependencies
* Tue Dec 12 2017 msrb@suse.com
- Remove build dependency on Mesa-devel, it is not needed. Add
  build dependency on damageproto-devel which is needed and was
  pulled in by Mesa-devel before.
* Fri Sep  8 2017 sndirsch@suse.com
- Update to version 7.10.0
  * Clients can now use DRI page flipping even while TearFree is enabled
  for any CRTC. This should improve performance of such clients
  (including compositing managers) while TearFree is enabled, and avoid
  other issues such as tearing on other CRTCs where TearFree isn't
  enabled.
  * The driver now takes measures to prevent other DRM master processes
  (potentially from other local users) from accessing buffers created by
  this driver while switched away to a different VT. Other DRM master
  processes should only be able to access a single buffer anymore, which
  contains only all-black pixels.
  * The gamma ramp is now applied to the HW cursor as well, so the HW
  cursor doesn't look odd when e.g. using Redshift or similar tools.
  * Plus other improvements and fixes. Thanks to everybody who
  contributed to this release in any way!
* Thu Apr 13 2017 sndirsch@suse.com
- SLE merge (missing fate/bugzilla entries)
  * bsc#990066 (we have even newer version than 7.7 meanwhile)
  * fate #320388 (factory is building against an even higher
    Xserver version, so covered as well)
  * fate #315643-315645, 319159-319161, 319618 (we have the latest
    available radeon driver X driver)
  * bsc#936452, FATE#319131 (seems this macro is no longer been used
    also in sle12-sp2)
  * bnc#896378 (also handled in factory, but patch is meanwhile
    upstream and included in driver release 7.9.0)
* Thu Mar 16 2017 mpluskal@suse.com
- Update to version 7.9.0:
  * Allow TearFree to be toggled at runtime via an RandR output
    property  "TearFree". The xorg.conf option "TearFree" now
    controls the default value of the output properties.
  * Use glamor by default for 2D acceleration with >= R600 and
    Xorg >= 1.18.3.
  * Ship 10-radeon.conf xorg.conf.d snippet for Xorg >= 1.16, so
    that the radeon driver can be loaded automatically even when
    the ati wrapper driver isn't installed.
  * Support loading the amdgpu driver from the ati wrapper driver.
  * Use DRM render nodes for DRI3 clients when available.
  * Plus many other improvements and fixes.
* Sat Nov 19 2016 tobias.johannes.klausmann@mni.thm.de
- Update to version 7.8.0:
  This release supports xserver versions 1.10-1.19.
  Highlights:
  + Significant 2D compositing performance increase, in particular with
    glamor enabled.
  + Option "TearFree" can now prevent tearing in all possible display
    configurations (with current versions of Xorg). Specifically, it's
    now also effective with arbitrary RandR transforms and with RandR 1.4
    slave output.
  + DRI3 is now enabled by default if the Xorg version is >= 1.18.3 and
    glamor is enabled.
  + DRI3/Present asynchronous page flips are now supported (requires
    corresponding kernel driver support, available in current versions of
    the Linux kernel). This can increase performance of fullscreen
    applications with sync-to-vblank disabled.
  + The HW cursor can now be used with RandR 1.4 slave output or with
    TearFree & rotation.
  + Performance improvements with RandR 1.4 slave output.
  + The list of supported GPUs in the Xorg log file has been slightly
    tidied up.
  + RandR 1.4 provider capabilities are now advertised more accurately.
- Remove upstream patches:
  + U_01-dri3-Return-NULL-from-radeon_dri3_pixmap_from_fd-if-calloc-fails.patch
  + U_02-Add-support-for-async-flips-to-radeon_do_pageflip.patch
  + U_03-present-Support-async-flips.patch
  + U_04-Enable-DRI3-by-default-when-building-for-Xorg-1.18.3.patch
  + U_05-EXA-6xx-7xx-fast-solid-pixmap-support.patch
  + U_06-EXA-6xx-7xx-accelerate-PictOpOver-with-component-alpha.patch
  + U_07-Adapt-to-XF86_CRTC_VERSION-7.patch
  + U_08-Add-explicit-RADEON_DRM_QUEUE_ERROR-define.patch
  + U_09-Don-t-enable-DRI3-by-default-with-EXA.patch
  + U_10-Use-EventCallback-to-avoid-flushing-every-time-in-the-FlushCallback.patch
  + U_11-Keep-track-of-damage-event-related-flushes-per-client-v2.patch
  + U_12-Use-drmmode_crtc_scanout_-helpers-for-RandR-1.4-scanout-pixmaps.patch
  + U_13-Handle-RandR-1.4-slave-dirty-updates-via-radeon_drm_queue.patch
  + U_14-Track-damage-accurately-for-RandR-1.4-slave-scanout.patch
  + U_15-Fix-build-against-xserver-1.13.patch
  + U_16-Only-copy-from-screen-pixmap-to-shared-pixmap-on-demand-for-slave-scanout.patch
  + U_17-Factor-out-transform_region-helper.patch
  + U_18-Move-up-radeon_scanout_extents_intersect.patch
  + U_19-Synchronize-scanout-pixmaps-for-TearFree.patch
  + U_20-Make-TearFree-effective-with-PRIME-slave-scanout.patch
  + U_21-Refactor-radeon_mode_hotplug.patch
  + U_22-Use-pRADEONEnt-to-find-both-screens-of-a-GPU-in-radeon_mode_hotplug.patch
* Thu Nov 10 2016 mstaudt@suse.com
- U_21-Refactor-radeon_mode_hotplug.patch
  U_22-Use-pRADEONEnt-to-find-both-screens-of-a-GPU-in-radeon_mode_hotplug.patch
  Fix enumeration of connectors per GPU (bsc#1008200).
* Fri Oct 14 2016 mstaudt@suse.com
- U_01-dri3-Return-NULL-from-radeon_dri3_pixmap_from_fd-if-calloc-fails.patch
  U_02-Add-support-for-async-flips-to-radeon_do_pageflip.patch
  U_03-present-Support-async-flips.patch
  U_04-Enable-DRI3-by-default-when-building-for-Xorg-1.18.3.patch
  U_05-EXA-6xx-7xx-fast-solid-pixmap-support.patch
  U_06-EXA-6xx-7xx-accelerate-PictOpOver-with-component-alpha.patch
  U_07-Adapt-to-XF86_CRTC_VERSION-7.patch
  U_08-Add-explicit-RADEON_DRM_QUEUE_ERROR-define.patch
  U_09-Don-t-enable-DRI3-by-default-with-EXA.patch
  U_10-Use-EventCallback-to-avoid-flushing-every-time-in-the-FlushCallback.patch
  U_11-Keep-track-of-damage-event-related-flushes-per-client-v2.patch
  U_12-Use-drmmode_crtc_scanout_-helpers-for-RandR-1.4-scanout-pixmaps.patch
  U_13-Handle-RandR-1.4-slave-dirty-updates-via-radeon_drm_queue.patch
  U_14-Track-damage-accurately-for-RandR-1.4-slave-scanout.patch
  U_15-Fix-build-against-xserver-1.13.patch
  U_16-Only-copy-from-screen-pixmap-to-shared-pixmap-on-demand-for-slave-scanout.patch
  U_17-Factor-out-transform_region-helper.patch
  U_18-Move-up-radeon_scanout_extents_intersect.patch
  U_19-Synchronize-scanout-pixmaps-for-TearFree.patch
  U_20-Make-TearFree-effective-with-PRIME-slave-scanout.patch
  Include patches that haven't made it into the 7.7.1 release.
  This means almost all commits between xf86-video-ati-7.7.0
  and 12d30eeb9711bd2b1609d6bbb74c4a1760596f72.
  Fixes (bsc#990066).
* Mon Sep 19 2016 tobias.johannes.klausmann@mni.thm.de
- Update to version 7.7.1:
  This release supports xserver versions 1.9-1.18.
  This is a stable point release containing only fixes for crash/hang/
  corruption bugs and other minor changes.
* Fri Apr  8 2016 sndirsch@suse.com
- Update to version 7.7:
  * Option "TearFree" can now prevent tearing with rotation/reflection as
    well (with Xorg >= 1.16).
  * RandR CRTC transforms now work correctly (but for now still exhibit
    tearing even with TearFree).
  * The RandR 1.4 provider name is now no longer hardcoded to "radeon"
    but constructed from the GPU chipset name and bus ID, allowing
    several GPUs supported by this driver to be distinguished by name.
  * The RandR primary output is now always explicitly marked as such.
  * The driver can now make use of more than 256MB of VRAM for scanout
    buffers, allowing e.g. virtual desktop sizes >= 8192x8192 to work.
  * The driver can prevent clients trying to use the DRI3 extension over a
    display connection forwarded via SSH from hanging.
  * Many more fixes for issues using the DRI3/Present extensions.
* Fri Nov 13 2015 mpluskal@suse.com
- Use url for source
- Add gpg signature
- Make building more verbose
* Fri Nov 13 2015 jimmy@boombatower.com
- Update to version 7.6.1:
  + Post 7.6.0 release version bump
  + Remove duplicate free(output_ids) call
  + Set version for 7.6.1 release
- Update to version 7.6.0:
  + Remove dead accelDFS flag
  + radeon: bump version post release
  + add new bonaire pci id
  + add new OLAND pci id
  + radeon: stop caching mode resources
  + radeon: move output name creation to its own function
  + radeon: add support for DP 1.2 display hotplug (v2)
  + radeon: adopt for new X server dirty tracking APIs.
  + radeon: cleanup the entity rec
  + radeon: move radeon_pixmap forward declaration into other block
  + radeon/vdpau: don't report VDPAU for < r300
  + Handle tiling in radeon_set_shared_pixmap_backing
  + Do not link radeon_drv.so against libpciaccess
  + Avoid leaking memory on output.
  + Proper leak fix, previous leak fix was bogus.
  + present: Move check for async flips
  + present: Fix present notify timestamps and counts.
  + Allow/Fix use of multiple ZaphodHead outputs per x-screen. (v2)
  + Don't set TILE_SPLIT flags if surface.tile_split == 0.
  + Fix inconsistent default eg_tile_split in evergreen_accel.c
  + Make selection between DRI2 and DRI3 consistent with other drivers. (v2)
  + Remove duplicate OPTION_PAGE_FLIP entry
  + PRIME: Don't advertise offload capabilities when acceleration is disabled
  + Prefer drmModeSetCursor2 over drmModeSetCursor
  + Require at least xserver 1.8
  + Move xorg_list backwards compatibility to new radeon_list.h header
  + Add DRM event queue helpers v2
  + DRI2: Simplify blit fallback handling for scheduled swaps
  + DRI2: Remove superfluous assignments to *_info->frame
  + DRI2: Move radeon_dri2_flip_event_handler
  + DRI2: Use helper functions for DRM event queue management v3
  + DRI2: Split out helper for getting UST and MSC of a specific CRTC
  + Move #include "radeon_glamor.h" from radeon.h to where it's needed
  + Fold radeon_glamor_flush into radeon_cs_flush_indirect
  + Add support for SYNC extension fences v2
  + Add support for the Present extension v2
  + Add DRI3 support v2
  + Simplify includes in radeon_{dri3,present}.c
  + Add xorg_list_for_each_entry_safe fallback in radeon_list.h
  + Initialize boolean variable before calling xf86GetOptValBool
  + DRI3: Use open hook instead of open_client
  + Always include misync.h before other misync headers
  + glamor: Add glamor_fd_from_pixmap define for standalone glamor tree
  + dri3: Use screen->CreatePixmap instead of fbCreatePixmap directly
  + EXA: Return NULL from radeon_get_pixmap_bo if there is no driver private
  + configure.ac: Check for misyncshm.h again
  + Adapt radeon_sync.c for misyncshm.h vs misync.h as well
  + Make radeon_do_pageflip take a BO handle directly
  + Present: Add radeon_present_get_pixmap_handle helper
  + glamor: Avoid generating GEM flink names for BOs shared via DRI3 v2
  + glamor: Handle GLAMOR_* flags removed from xserver
  + Increase robustness against DRM page flip ioctl failures v3
  + Simplify radeon_do_pageflip() error handling slightly more
  + Move radeon_drm_handler/abort_proc fields to drmmode_flipdata_rec
  + Move get_pixmap_handle helper to radeon_bo_helper.c
  + DRI2: Use radeon_get_pixmap_handle
  + Only enable SYNC extension fences and the Present extension along with DRI3
  + Add radeon_get_pixmap_tiling_flags helper
  + present: Don't flip between BOs with different tiling parameters
  + Rename scanout_pixmap_x field to prime_pixmap_x
  + Split out struct drmmode_scanout for rotation shadow buffer information
  + Add RADEON_CREATE_PIXMAP_SCANOUT flag
  + glamor: Remove unused function radeon_glamor_pixmap_is_offscreen
  + glamor: Add radeon_pixmap parameter to radeon_glamor_create_textured_pixmap
  + glamor: Add wrappers for the X server rendering hooks
  + glamor: Add Option "ShadowPrimary" v2
  + glamor: Remove the stride member of struct radeon_pixmap
  + Add Option "TearFree" v4
  + DRI2: Clear old->devPrivate.ptr in fixup_glamor
  + Only copy fbcon BO contents if bgNoneRoot is TRUE
  + Defer initial drmmode_copy_fb call until root window creation
  + Defer initial modeset until the first BlockHandler invocation
  + Update scanout pixmap contents before setting a mode with it
  + Make drmmode_copy_fb() work with glamor as well
  + On screen resize, clear the new buffer before displaying it
  + Don't call radeon_get_pixmap_private() when using EXA
  + Skip disabled CRTCs in drmmode_set_desired_modes() even if set_hw == FALSE
  + glamor: Deal with glamor_glyphs_init being removed from xserver
  + Replace SyncFence typedef with declaration of struct _SyncFence
  + present: Remove get_drmmode_crtc helper
  + glamor: Only wait for GPU writes in radeon_glamor_prepare_access_cpu_ro
  + DRI2: Fix handling of drmmode_crtc_get_ust_msc return code
  + Don't attempt a DRI2/Present page flip while the other one is flipping
  + Skip disabled CRTCs in radeon_scanout_(do_)update
  + present: Fall back to modeset for unflip operation
  + present: Look at all CRTCs to determine if we can flip
  + present: Handle DPMS off in radeon_present_get_ust_msc
  + Remove unused local variable pRADEONEnt
  + glamor: Move declaration of struct radeon_pixmap out of #if/#else blocks
  + Only call drmmode_copy_fb (at most) once on server startup
  + Wait for scanout BO initialization to finish before setting mode
  + DRI2: Don't ignore rotated CRTCs in amdgpu_dri2_drawable_crtc
  + DRI2: Keep MSC monotonic when moving window between CRTCs
  + Only align screen / scanout pixmap height where necessary
  + Call xf86CrtcRotate from initial drmmode_set_desired_modes call
  + Don't advertise rotation support without hardware acceleration v2
  + Eliminate redundant data parameter from drmmode_crtc_scanout_create
  + Properly handle drmModeAddFB failure in drmmode_crtc_scanout_allocate
  + Bump version for 7.6.0 release
  + Disable CRTCs when disabling the outputs
  + Do not try to enable already enabled CRTCs in DPMS hook
  + radeon: remove unneeded inclusion of sarea.h
  + Handle failures in setting a CRTC to a DRM mode properly
  + dri2: Avoid calculation with undefined msc value
  + Simplify pick best crtc to fold two loops into one
  + Clean up allocation in RADEONInitVideo()
  + Simplify drmmode_set_mode_major() and avoid leaking memory.
  + Clean up radeon_dri2_create_buffer2()
- Remove upstream patches:
  * U_glamor-Handle-GLAMOR_-flags-removed-from-xserver.patch
  * U_radeon-adopt-for-new-X-server-dirty-tracking-APIs.patch
* Wed Nov 11 2015 sndirsch@suse.com
- U_radeon-adopt-for-new-X-server-dirty-tracking-APIs.patch
  * adopt for new X server dirty tracking APIs, which came with
    xorg-server 1.18.0
- U_glamor-Handle-GLAMOR_-flags-removed-from-xserver.patch
  * Handle GLAMOR_* flags removed from xserver. The behaviour is
    the same as when the removed flags were passed in.
* Fri Oct  3 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 7.5.0:
  + radeon: enable hawaii accel conditionally (v3)
  + radeon: fix warnings when building against older xservers
  + radeon/kms: add new CIK pci ids
  + radeon/kms: add new SI pci ids
  + radeon/kms: fix mullins pci id
  + radeon: require libdrm_radeon 2.4.58 for latest SI/CI pci ids
  + radeon: drop redundant radeon_drm.h includes
  + radeon: move RADEON_TILING_{MASK, LINEAR} from radeon_drm.h to radeon.h
  + radeon: drop radeon_drm.h
  + radeon: remove definitions already present in radeon_drm.h
  + glamor.hfigure: Include xorg-server.h before
  + Handle CRTC DPMS from output DPMS hooks
  + Add Emacs .dir-local.el file
  + radeon: fix a leak in radeon_vbo_get_bo()
  + radeon: fix build warnings regarding const qualifier
- Remove upstream patch:
  U_Handle-CRTC-DPMS-from-output-DPMS-hooks.patch
* Fri Sep 12 2014 sndirsch@suse.com
- U_Handle-CRTC-DPMS-from-output-DPMS-hooks.patch
  * Handle CRTC DPMS from output DPMS hooks (bnc#896378)
* Fri Jun 27 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 7.4.0:
  + kms: Use own thunk function instead of shadowUpdatePackedWeak
  + radeon: don't install colormap handling if there are no crtcs
  + radeon: require libdrm 2.4.51
  + radeon: enable tiling by default on CIK
  + update man page to reflect tiling changes for CI parts
  + radeon: require libdrm_radeon 2.4.54 for mullins support
  + radeon: enable tiling for mullins
  + radeon: fix use-after-free in modesetting cleanup
  + radeon_open_drm_master get rid of unnecessary goto
  + Add radeon_get_drm_master_fd helper function
  + Add support for server managed fds
  + Fix building on older servers without xf86platformBus.h
  + evergreen: fix shader constant upload on ppc
  + return immediately in preinit when called with PROBE_DETECT
  + Only log debugging output about initializing colormaps when we're doing so
  + Allow enabling glamor on R500 (and R300) class 3D engines as well.
  + Build against glamor in the xserver tree if available
  + dri2: Fix conflicting CreatePixmap usage flag definitions
  + glamor: Fix test for creating shared pixmaps
  + Adapt to load_cursor_argb signature change in xserver 1.15.99.902
  + dri2: Handle PRIME for source buffer as well in radeon_dri2_copy_region2
  + Revert "Adapt to load_cursor_argb signature change in xserver 1.15.99.902"
  + Don't disable acceleration on >= SI on attempts to force EXA
  + Rename Option "NoAccel" to "Accel"
  + radeon: add support for Mullins.
  + radeon: add Mullins pci ids.
* Tue Mar 18 2014 sndirsch@suse.com
- remove URL in specfile sourceline for snapshot tarball in the
  hope to be accepted by buildservice now
* Mon Mar 17 2014 tobias.johannes.klausmann@mni.thm.de
- Update to latest git version bdc412044f6ced056cd57320d1b2ee0d967c219
- Add conditional for X-Server internal glamor vs standalone glamor
* Thu Jan 30 2014 sndirsch@suse.com
- Update to 7.3.0; changes since 7.2.0:
    radeon: disallow glamor on pre-R600 asics
    radeon/kms: add berlin pci ids
    radeon: enable glamor by default (v4)
    radeon: fix limit handling for cards with >4G of ram
    drm/radeon: fix non-glamor build
    radeon: fix the non-glamor build harder...
    radeon: enable tiling on SI by default (v2)
    radeon: add support for Hawaii
    radeon/kms: add Hawaii pci ids
    drm/radeon: fix SUMO2 pci id
    radeon/exa: Always use a scratch surface for UTS to vram
    Require glamor 0.6.0
    EXA/evergreen: Paranoia around linear tiling. (v2)
    radeon: use glamor Xv support if present.
    radeon/glamor: with new pixmap for dri2 drawable no need to
    create new texture
    Fix shadowfb on big-endian machines
    DRI2: Install client callback only once
    dri2: Make last_vblank_seq local unsigned to match dpms_last_seq
    Don't require the glamoregl module to be pre-loaded with xserver >= 1.15
    radeon: Set first parameter of drmOpen() to NULL
    radeon: Restore kernel module load on FreeBSD.
    radeon: disable 2D tiling on buffers < 128 pixels
- removed obsolete patches xf86-video-ati.diff,
  xf86-video-ati-bug519261-increase-virtual.diff,
  xf86-video-ati-disable-dri-bug437651-ia64only.diff since
  modesetting is now being done in kernel space (KMS) and IA64 is
  no longer considered a relevant architecture for current SUSE
  products
- specfile cleanup
* Wed Aug  7 2013 hrvoje.senjan@gmail.com
- Update to 7.2.0:
  - Changes since 7.1.0_git20130705 snapshot:
  + Fix RADEON_FALLBACK logging
  + EXA/evergreen/ni: optimize non-overlapping Copy
  + EXA/evergreen/ni: fast solid pixmap support
  + EXA/evergreen/ni: accelerate PictOpOver with component alpha
  + EXA/evergreen/ni: replace magic number
  + radeon: add support for reverse prime (v2)
  + drmmode: add support for multi-screen reverse optimus
  + radeon: fix naming clashes with multiple GPUs (v3)
  + EXA/6xx/7xx: optimize non-overlapping Copy
  + kill unused radeon_driver.c
  + add bicubic_table.py to EXTRA_DIST
* Wed Aug  7 2013 ro@suse.de
- add ExcludeArch for s390 and s390x
* Fri Jul  5 2013 hrvoje.senjan@gmail.com
- Update to 7.1.0_git20130705 snapshot:
  + radeon/kms: add kabini pci ids
  + radeon/kms: add bonaire pci ids
  + radeon: update cursor handling for CIK
  + radeon: add family ids for CIK
  + radeon: add family ids for CIK
  + radeon: fix a memory leak in get_modes() callback.
  + handfull of DRI2 fixes
  + radeon: add Hainan pci ids
  + radeon: add hainan chip family
  + radeon: add new richland pci ids
  + radeon: add new SI pci ids
  + radeonsi: add 2d tiling support
  + glamor: Only enable for depth >= 24
  + glamor: Enable by default on SI
  + radeon: add Richland pci ids
  + radeon: add oland chip family
* Wed Mar 20 2013 sndirsch@suse.com
- introduce hardware supplements conditional on xorg-x11-server
  package (bnc#810333)
* Thu Jan 31 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 7.1.0:
    radeon: add new SI pci id
    radeon: fix ring count in R300PrepareTexturedVideo
    exa/Xv: fix coordinate limits on AVIVO IGPs
    radeon/r200: program RE_WIDTH_HEIGHT properly
    radeon: fix damage reporting for slave pixmaps
    video: add option to include disabled CRTCs in best CRTC search
    DRI2: change signature of radeon_dri2_drawable_crtc
    DRI2: limit the swap rate when CRTC is in DPMS-off state
    radeon: avoid segfault when pixmap exceed GPU capabilities
    radeon: avoid copying over itself ddx fb
    Remove dead code flagged by gcc -Wunused-but-set-variable.
    Remove unused local variable 'path'.
    Remove local variables total_size_bytes.
    Remove dead option definitions.
    glamor: Release the drawable after passing to glamor_push_pixels
    glamor: Enable full 2D acceleration for SI as well.
    Drop support for X servers older than 1.7.
    DRI2: Properly use buffer depth passed in by client.
    DRI2/r[345]xx: 16 bit depth buffers use square micro tiling.
    Make CRTC shadow pixmaps usable by glamor.
    Make radeon_glamor_create_textured_pixmap() return TRUE without USE_GLAMOR.
* Tue Nov  6 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 7.0.0:
  This is the first KMS only release.  Major changes:
  + Enable 2D tiling by default on r6xx+ asics
    (requires mesa 9.0+).  If you are planning to
    ship xf86-video-ati 7.x with an older version of
    mesa, please disable 2D tiling.
  + xserver 1.13 support including prime
  + glamor support
  + SI support
* Wed Oct 17 2012 tobias.johannes.klausmann@mni.thm.de
- Update to git commit #ce1b745dcb60dc516ad999756240b78e72a7aa54:
  + Bump package version to 6.98.1
  (the driver identifies itself as 6.99.99)
* Thu Sep 20 2012 sndirsch@suse.com
- updated to git commit #8637f77
  + glamor: Force acceleration for DRI2 copies.
    Improves performance of non-pageflipped 3D apps on SI.
* Fri Jun 29 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 6.14.6
  - radeon: dixPrivateKeyRegistered is only in server 1.9
  - radeon: require libdrm 2.4.36 for KMS support.
  - UMS: Fix CRTC DPMS state check.
  - Fix up displayWidth vs. virtualX confusion in radeon_setup_kernel_mem().
- Removed patches: (Fixed in this release)
  - U_UMS-Fix-CRTC-DPMS-state-check.patch
- Theatre drivers removed
* Fri Jun 15 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 6.14.5
  New in this Release:
    + add solid picture accel
    + tiling fixes
    + new pci ids
    + 6xx-9xx Xv improvements
    + support for upcoming xserver API changes
    + bug fixes
  Added patch:
    U_UMS-Fix-CRTC-DPMS-state-check.patch
  Removed patches: (Fixed in this release)
    U_xf86-video-ati-6.14.4-exa-solid-accel-evergreen.patch
    U_xf86-video-ati-6.14.4-exa-solid-accel-r100.patch
    U_xf86-video-ati-6.14.4-exa-solid-accel-r200.patch
    U_xf86-video-ati-6.14.4-exa-solid-accel-r300.patch
    U_EXA-Attempt-to-fix-solid-picture-acceleration-with-U.patch
    U_EXA-UMS-Synchronize-to-the-GPU-before-writing-solid-.patch
* Fri Jun  8 2012 sndirsch@suse.com
- U_EXA-UMS-Synchronize-to-the-GPU-before-writing-solid-.patch
  * that one is required to fix the rendering corruption in UMS
    introduced with the previous patch (bnc#765973)
* Fri Jun  8 2012 sndirsch@suse.com
- U_EXA-Attempt-to-fix-solid-picture-acceleration-with-U.patch
  * Attempt to fix solid picture acceleration with UMS. (fdo#49182,
    bnc#765973)
* Wed May 16 2012 idonmez@suse.com
- Add upstream patches to accelerate solid pictures, fixes color
  corruption problems with new cairo.
* Thu Apr 19 2012 dimstar@opensuse.org
- Update to version 6.14.4:
  + bump libdrm requirement for TN support
  + radeon/kms: add TN pci ids
  + r6xx: initialize SX_MISC
  + DRI2: Unreference buffers immediately when event wait info is
    invalidated.
  + Re-register DRM FD wakeup handler for each server generation.
  + Bugs fixed: fdo#45827, fdo#45937, fdo#45829, fdo#43893.
- Drop patches:
  + xf86-video-ati-bug474071-fix2.diff
  + xf86-video-ati-ia64_screen_blank.diff
- Use %%x11_abi_videodrv_req instead of static ABI Requires.
* Wed Apr 18 2012 vuntz@opensuse.org
- Split xf86-video-ati from xorg-x11-driver-video.
  Initial version: 6.14.3.
